summaryrefslogtreecommitdiff
path: root/sys/arch/mac68k
diff options
context:
space:
mode:
authorJoel Sing <jsing@cvs.openbsd.org>2008-01-23 16:37:59 +0000
committerJoel Sing <jsing@cvs.openbsd.org>2008-01-23 16:37:59 +0000
commit7f1108670a2ba0bd92c2a3691e98bc89725e6589 (patch)
treeb334068e0263bb1f8a52cc8ec13e75efc2b74092 /sys/arch/mac68k
parentc55bd1fde22d7d1558a234e1b9f927f4f88e19ff (diff)
Cleanup cn_pri. Change constants to more meaningful names, rather than
the hp300 related ones currently in use. CN_NORMAL becomes CN_LOWPRI, CN_INTERNAL becomes CN_MIDPRI and CN_REMOTE becomes CN_HIGHPRI. ok miod@
Diffstat (limited to 'sys/arch/mac68k')
-rw-r--r--sys/arch/mac68k/dev/zs.c10
-rw-r--r--sys/arch/mac68k/mac68k/wscons_machdep.c6
2 files changed, 8 insertions, 8 deletions
diff --git a/sys/arch/mac68k/mac68k/wscons_machdep.c b/sys/arch/mac68k/mac68k/wscons_machdep.c
index 1d8b442f829..7771cfeedb8 100644
--- a/sys/arch/mac68k/mac68k/wscons_machdep.c
+++ b/sys/arch/mac68k/mac68k/wscons_machdep.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: wscons_machdep.c,v 1.5 2006/01/18 23:21:17 miod Exp $ */
+/* $OpenBSD: wscons_machdep.c,v 1.6 2008/01/23 16:37:56 jsing Exp $ */
/* $NetBSD: maccons.c,v 1.5 2005/01/15 16:00:59 chs Exp $ */
/*
@@ -62,7 +62,7 @@ wscnprobe(struct consdev *cp)
#endif
cp->cn_dev = NODEV;
- cp->cn_pri = CN_NORMAL;
+ cp->cn_pri = CN_LOWPRI;
#if NWSDISPLAY > 0
unit = 0;
@@ -71,7 +71,7 @@ wscnprobe(struct consdev *cp)
break;
if (maj != nchrdev) {
- cp->cn_pri = CN_INTERNAL;
+ cp->cn_pri = CN_MIDPRI;
cp->cn_dev = makedev(maj, unit);
}
#endif
diff --git a/sys/arch/mac68k/dev/zs.c b/sys/arch/mac68k/dev/zs.c
index 749a104f753..b1af641730f 100644
--- a/sys/arch/mac68k/dev/zs.c
+++ b/sys/arch/mac68k/dev/zs.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: zs.c,v 1.25 2007/11/24 12:59:28 jmc Exp $ */
+/* $OpenBSD: zs.c,v 1.26 2008/01/23 16:37:56 jsing Exp $ */
/* $NetBSD: zs.c,v 1.19 1998/01/12 19:22:18 thorpej Exp $ */
/*
@@ -944,8 +944,8 @@ zscnsetup()
* be the console (as defined in mac68k/conf.c) gets probed. The probe
* fills in the consdev structure. Important parts are the device #,
* and the console priority. Values are CN_DEAD (don't touch me),
* CN_NORMAL (I'm here, but elsewhere might be better), CN_INTERNAL
* (the video, better than CN_NORMAL), and CN_REMOTE (pick me!)
*
* As the mac's a bit different, we do extra work here. We mainly check
* to see if we have serial echo going on. Also chould check for default
@@ -963,9 +963,9 @@ zscnprobe(struct consdev * cp)
}
}
if (maj != nchrdev) {
- cp->cn_pri = CN_NORMAL; /* Lower than CN_INTERNAL */
+ cp->cn_pri = CN_LOWPRI;
if (mac68k_machine.serial_console != 0) {
- cp->cn_pri = CN_REMOTE; /* Higher than CN_INTERNAL */
+ cp->cn_pri = CN_HIGHPRI;
mac68k_machine.serial_boot_echo =0;
}
@@ -944,8 +944,8 @@ zscnsetup()
* fills in the consdev structure. Important parts are the device #,
* and the console priority. Values are CN_DEAD (don't touch me),
- * CN_NORMAL (I'm here, but elsewhere might be better), CN_INTERNAL
- * (the video, better than CN_NORMAL), and CN_REMOTE (pick me!)
+ * CN_LOWPRI (I'm here, but elsewhere might be better), CN_MIDPRI
+ * (the video, better than CN_LOWPRI), and CN_HIGHPRI (pick me!)
*
* As the mac's a bit different, we do extra work here. We mainly check